# Reference

```{eval-rst}
.. autofunction:: haplo.analysis.combine_constantinos_kalapotharakos_split_mcmc_output_files_to_xarray_zarr
.. autofunction:: haplo.analysis.mcmc_output_xarray_dataset_to_pandas_data_frame
.. autofunction:: haplo.analysis.slice_iteration_of_mcmc_output_xarray_dataset
```
